@@ -14,6 +14,7 @@ from faker.providers.person.en import Provider as EnProvider
 from faker.providers.person.en_GB import Provider as EnGBProvider
 from faker.providers.person.en_IE import Provider as EnIEProvider
 from faker.providers.person.en_IN import Provider as EnINProvider
+from faker.providers.person.en_NG import Provider as EnNgProvider
 from faker.providers.person.en_PK import Provider as EnPKprovider
 from faker.providers.person.en_US import Provider as EnUSProvider
 from faker.providers.person.es import Provider as EsProvider
@@ -23,9 +24,11 @@ from faker.providers.person.fi_FI import Provider as FiProvider
 from faker.providers.person.fr_BE import Provider as FrBEProvider
 from faker.providers.person.ga_IE import Provider as GaIEProvider
 from faker.providers.person.gu_IN import Provider as GuINProvider
+from faker.providers.person.ha_NG import Provider as HaNgProvider
 from faker.providers.person.he_IL import Provider as HeILProvider
 from faker.providers.person.hi_IN import Provider as HiINProvider
 from faker.providers.person.hy_AM import Provider as HyAmProvider
+from faker.providers.person.ig_NG import Provider as IgNgProvider
 from faker.providers.person.is_IS import Provider as IsISProvider
 from faker.providers.person.lv_LV import Provider as LvProvider
 from faker.providers.person.ne_NP import Provider as NeProvider
@@ -343,6 +346,54 @@ class TestEnGB(unittest.TestCase):
         return names[1]
 
 
+class TestEnNG(unittest.TestCase):
+    """Tests person in the en_NG (English - Nigeria) locale"""
+
+    def setUp(self):
+        self.fake = Faker("en_NG")
+        Faker.seed(0)
+
+    def test_name(self):
+        name = self.fake.name()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_female()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_male()
+        self.assertIsInstance(name, str)
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.first_names
+
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.first_names
+        assert name in EnNgProvider.first_names_female
+
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.first_names
+        assert name in EnNgProvider.first_names_male
+
+    def test_last_name(self):
+        assert hasattr(EnNgProvider, "last_names")
+
+        name = self.fake.last_name()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.last_names
+
+        name = self.fake.last_name_female()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.last_names
+
+        name = self.fake.last_name_male()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.last_names
+
+
 class TestEnIE(unittest.TestCase):
     """Tests person in the en-IE locale"""
 
@@ -826,6 +877,54 @@ class TestGuIN(unittest.TestCase):
         assert prefix in GuINProvider.prefixes_male
 
 
+class TestHaNG(unittest.TestCase):
+    """Tests person in the ha_NG (Hausa - Nigeria) locale"""
+
+    def setUp(self):
+        self.fake = Faker("ha_NG")
+        Faker.seed(0)
+
+    def test_name(self):
+        name = self.fake.name()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_female()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_male()
+        self.assertIsInstance(name, str)
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.first_names
+
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.first_names
+        assert name in HaNgProvider.first_names_female
+
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.first_names
+        assert name in HaNgProvider.first_names_male
+
+    def test_last_name(self):
+        assert hasattr(HaNgProvider, "last_names")
+
+        name = self.fake.last_name()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.last_names
+
+        name = self.fake.last_name_female()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.last_names
+
+        name = self.fake.last_name_male()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.last_names
+
+
 class TestHeIL(unittest.TestCase):
     """Tests person in the he_IL locale."""
 
@@ -959,6 +1058,54 @@ class TestHyAM(unittest.TestCase):
         assert name in HyAmProvider.last_names
 
 
+class TestIgNG(unittest.TestCase):
+    """Tests person in the ig_NG (Igbo - Nigeria) locale"""
+
+    def setUp(self):
+        self.fake = Faker("ig_NG")
+        Faker.seed(0)
+
+    def test_name(self):
+        name = self.fake.name()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_female()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_male()
+        self.assertIsInstance(name, str)
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.first_names
+
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.first_names
+        assert name in IgNgProvider.first_names_female
+
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.first_names
+        assert name in IgNgProvider.first_names_male
+
+    def test_last_name(self):
+        assert hasattr(IgNgProvider, "last_names")
+
+        name = self.fake.last_name()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.last_names
+
+        name = self.fake.last_name_female()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.last_names
+
+        name = self.fake.last_name_male()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.last_names
+
+
 class TestIsIS(unittest.TestCase):
     """Tests person in the is_IS locale"""
 
@@ -1734,7 +1881,7 @@ class TestYoNG(unittest.TestCase):
 
     def test_last_name(self):
         """
-        Test the generation of Zulu last names.
+        Test the generation of yoruba last names.
         """
         # There's no gender-specific last name in Zulu.
         self.assertTrue(hasattr(YoNGProvider, "last_names_male"))
@@ -1760,7 +1907,7 @@ class TestYoNG(unittest.TestCase):
 
     def test_first_name(self):
         """
-        Test the generation of Zulu first names.
+        Test the generation of yoruba first names.
         """
         # General first name.
         name = self.fake.first_name()
@@ -1781,7 +1928,7 @@ class TestYoNG(unittest.TestCase):
 
     def test_full_name(self):
         """
-        Test the generation of full Zulu names.
+        Test the generation of full yoruba names.
         """
         # Full name.
         name = self.fake.name()
